@@ -1,7 +1,7 @@
 """
 Type annotations for codeartifact service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codeartifact/type_defs.html)
 
 Usage::
 
@@ -18,11 +18,11 @@ from typing import Dict, List
 from botocore.response import StreamingBody
 
 from .literals import (
-    DomainStatus,
-    HashAlgorithm,
-    PackageFormat,
-    PackageVersionErrorCode,
-    PackageVersionStatus,
+    DomainStatusType,
+    HashAlgorithmType,
+    PackageFormatType,
+    PackageVersionErrorCodeType,
+    PackageVersionStatusType,
 )
 
 if sys.version_info >= (3, 8):
@@ -98,7 +98,7 @@ _OptionalAssetSummaryTypeDef = TypedDict(
     "_OptionalAssetSummaryTypeDef",
     {
         "size": int,
-        "hashes": Dict[HashAlgorithm, str],
+        "hashes": Dict[HashAlgorithmType, str],
     },
     total=False,
 )
@@ -228,7 +228,7 @@ DomainDescriptionTypeDef = TypedDict(
         "name": str,
         "owner": str,
         "arn": str,
-        "status": DomainStatus,
+        "status": DomainStatusType,
         "createdTime": datetime,
         "encryptionKey": str,
         "repositoryCount": int,
@@ -244,7 +244,7 @@ DomainSummaryTypeDef = TypedDict(
         "name": str,
         "owner": str,
         "arn": str,
-        "status": DomainStatus,
+        "status": DomainStatusType,
         "createdTime": datetime,
         "encryptionKey": str,
     },
@@ -282,7 +282,7 @@ GetPackageVersionAssetResultTypeDef = TypedDict(
 GetPackageVersionReadmeResultTypeDef = TypedDict(
     "GetPackageVersionReadmeResultTypeDef",
     {
-        "format": PackageFormat,
+        "format": PackageFormatType,
         "namespace": str,
         "package": str,
         "version": str,
@@ -329,7 +329,7 @@ ListDomainsResultTypeDef = TypedDict(
 ListPackageVersionAssetsResultTypeDef = TypedDict(
     "ListPackageVersionAssetsResultTypeDef",
     {
-        "format": PackageFormat,
+        "format": PackageFormatType,
         "namespace": str,
         "package": str,
         "version": str,
@@ -343,7 +343,7 @@ ListPackageVersionAssetsResultTypeDef = TypedDict(
 ListPackageVersionDependenciesResultTypeDef = TypedDict(
     "ListPackageVersionDependenciesResultTypeDef",
     {
-        "format": PackageFormat,
+        "format": PackageFormatType,
         "namespace": str,
         "package": str,
         "version": str,
@@ -358,7 +358,7 @@ ListPackageVersionsResultTypeDef = TypedDict(
     "ListPackageVersionsResultTypeDef",
     {
         "defaultDisplayVersion": str,
-        "format": PackageFormat,
+        "format": PackageFormatType,
         "namespace": str,
         "package": str,
         "versions": List["PackageVersionSummaryTypeDef"],
@@ -416,7 +416,7 @@ PackageDependencyTypeDef = TypedDict(
 PackageSummaryTypeDef = TypedDict(
     "PackageSummaryTypeDef",
     {
-        "format": PackageFormat,
+        "format": PackageFormatType,
         "namespace": str,
         "package": str,
     },
@@ -426,7 +426,7 @@ PackageSummaryTypeDef = TypedDict(
 PackageVersionDescriptionTypeDef = TypedDict(
     "PackageVersionDescriptionTypeDef",
     {
-        "format": PackageFormat,
+        "format": PackageFormatType,
         "namespace": str,
         "packageName": str,
         "displayName": str,
@@ -437,7 +437,7 @@ PackageVersionDescriptionTypeDef = TypedDict(
         "publishedTime": datetime,
         "licenses": List["LicenseInfoTypeDef"],
         "revision": str,
-        "status": PackageVersionStatus,
+        "status": PackageVersionStatusType,
     },
     total=False,
 )
@@ -445,7 +445,7 @@ PackageVersionDescriptionTypeDef = TypedDict(
 PackageVersionErrorTypeDef = TypedDict(
     "PackageVersionErrorTypeDef",
     {
-        "errorCode": PackageVersionErrorCode,
+        "errorCode": PackageVersionErrorCodeType,
         "errorMessage": str,
     },
     total=False,
@@ -455,7 +455,7 @@ _RequiredPackageVersionSummaryTypeDef = TypedDict(
     "_RequiredPackageVersionSummaryTypeDef",
     {
         "version": str,
-        "status": PackageVersionStatus,
+        "status": PackageVersionStatusType,
     },
 )
 _OptionalPackageVersionSummaryTypeDef = TypedDict(
@@ -518,7 +518,7 @@ RepositoryExternalConnectionInfoTypeDef = TypedDict(
     "RepositoryExternalConnectionInfoTypeDef",
     {
         "externalConnectionName": str,
-        "packageFormat": PackageFormat,
+        "packageFormat": PackageFormatType,
         "status": Literal["Available"],
     },
     total=False,
@@ -551,7 +551,7 @@ SuccessfulPackageVersionInfoTypeDef = TypedDict(
     "SuccessfulPackageVersionInfoTypeDef",
     {
         "revision": str,
-        "status": PackageVersionStatus,
+        "status": PackageVersionStatusType,
     },
     total=False,
 )
